@@ -10,19 +10,18 @@
 
 #include <KCalendarCore/Alarm>
 
-class QStringList;
+#include <QStringList>
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 enum {
     // Fallback in case config is invalid
     DEFAULT_REMINDER_OFFSET = 15 // minutes
 };
 
-namespace AlarmPresets {
-enum When {
-    BeforeStart,
-    BeforeEnd
-};
+namespace AlarmPresets
+{
+enum When { BeforeStart, BeforeEnd };
 
 /**
  * Returns the available presets.
