@@ -11,12 +11,13 @@
 
 #include "incidenceeditor_debug.h"
 #include <KActionCollection>
-#include <KToolBar>
 #include <KLocalizedString>
+#include <KToolBar>
 
 using namespace IncidenceEditorNG;
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 class IncidenceDescriptionPrivate
 {
 public:
@@ -37,11 +38,8 @@ IncidenceDescription::IncidenceDescription(Ui::EventOrTodoDesktop *ui)
     setObjectName(QStringLiteral("IncidenceDescription"));
     mUi->mRichTextLabel->setContextMenuPolicy(Qt::NoContextMenu);
     setupToolBar();
-    connect(mUi->mRichTextLabel, &QLabel::linkActivated, this,
-            &IncidenceDescription::toggleRichTextDescription);
-    connect(
-        mUi->mDescriptionEdit->richTextComposer(), &KPIMTextEdit::RichTextComposer::textChanged, this,
-        &IncidenceDescription::checkDirtyStatus);
+    connect(mUi->mRichTextLabel, &QLabel::linkActivated, this, &IncidenceDescription::toggleRichTextDescription);
+    connect(mUi->mDescriptionEdit->richTextComposer(), &KPIMTextEdit::RichTextComposer::textChanged, this, &IncidenceDescription::checkDirtyStatus);
 }
 
 IncidenceDescription::~IncidenceDescription()
@@ -59,12 +57,10 @@ void IncidenceDescription::load(const KCalendarCore::Incidence::Ptr &incidence)
         enableRichTextDescription(incidence->descriptionIsRich());
         if (incidence->descriptionIsRich()) {
             mUi->mDescriptionEdit->richTextComposer()->setHtml(incidence->richDescription());
-            d->mRealOriginalDescriptionEditContents
-                = mUi->mDescriptionEdit->richTextComposer()->toHtml();
+            d->mRealOriginalDescriptionEditContents = mUi->mDescriptionEdit->richTextComposer()->toHtml();
         } else {
             mUi->mDescriptionEdit->richTextComposer()->setPlainText(incidence->description());
-            d->mRealOriginalDescriptionEditContents
-                = mUi->mDescriptionEdit->richTextComposer()->toPlainText();
+            d->mRealOriginalDescriptionEditContents = mUi->mDescriptionEdit->richTextComposer()->toPlainText();
         }
     } else {
         enableRichTextDescription(false);
@@ -95,13 +91,9 @@ bool IncidenceDescription::isDirty() const
        any transformation regarding non-printable chars will be irrelevant.
     */
     if (d->mRichTextEnabled) {
-        return !mLoadedIncidence->descriptionIsRich()
-               || d->mRealOriginalDescriptionEditContents
-               != mUi->mDescriptionEdit->richTextComposer()->toHtml();
+        return !mLoadedIncidence->descriptionIsRich() || d->mRealOriginalDescriptionEditContents != mUi->mDescriptionEdit->richTextComposer()->toHtml();
     } else {
-        return mLoadedIncidence->descriptionIsRich()
-               || d->mRealOriginalDescriptionEditContents
-               != mUi->mDescriptionEdit->richTextComposer()->toPlainText();
+        return mLoadedIncidence->descriptionIsRich() || d->mRealOriginalDescriptionEditContents != mUi->mDescriptionEdit->richTextComposer()->toPlainText();
     }
 }
 
@@ -116,12 +108,10 @@ void IncidenceDescription::enableRichTextDescription(bool enable)
         rt = i18nc("@action Enable or disable rich text editing", "Disable rich text");
         placeholder = QStringLiteral("<a href=\"show\">&lt;&lt; %1</a>");
         mUi->mDescriptionEdit->richTextComposer()->activateRichText();
-        d->mRealOriginalDescriptionEditContents
-            = mUi->mDescriptionEdit->richTextComposer()->toHtml();
+        d->mRealOriginalDescriptionEditContents = mUi->mDescriptionEdit->richTextComposer()->toHtml();
     } else {
         mUi->mDescriptionEdit->richTextComposer()->switchToPlainText();
-        d->mRealOriginalDescriptionEditContents
-            = mUi->mDescriptionEdit->richTextComposer()->toPlainText();
+        d->mRealOriginalDescriptionEditContents = mUi->mDescriptionEdit->richTextComposer()->toPlainText();
     }
 
     placeholder = placeholder.arg(rt);
@@ -142,7 +132,7 @@ void IncidenceDescription::setupToolBar()
     KActionCollection *collection = new KActionCollection(this);
     mUi->mDescriptionEdit->richTextComposer()->createActions(collection);
 
-    auto *mEditToolBar = new KToolBar(mUi->mEditToolBarPlaceHolder);
+    auto mEditToolBar = new KToolBar(mUi->mEditToolBarPlaceHolder);
     mEditToolBar->setToolButtonStyle(Qt::ToolButtonIconOnly);
     mEditToolBar->addAction(collection->action(QStringLiteral("format_text_bold")));
     mEditToolBar->addAction(collection->action(QStringLiteral("format_text_italic")));
@@ -172,7 +162,7 @@ void IncidenceDescription::setupToolBar()
     mEditToolBar->addAction(collection->action(QStringLiteral("manage_link")));
     mUi->mDescriptionEdit->richTextComposer()->setEnableActions(false);
 
-    auto *layout = new QGridLayout(mUi->mEditToolBarPlaceHolder);
+    auto layout = new QGridLayout(mUi->mEditToolBarPlaceHolder);
     layout->addWidget(mEditToolBar);
 #endif
 
@@ -187,31 +177,18 @@ void IncidenceDescription::printDebugInfo() const
     qCDebug(INCIDENCEEDITOR_LOG) << "RichText enabled " << d->mRichTextEnabled;
 
     if (mLoadedIncidence) {
-        qCDebug(INCIDENCEEDITOR_LOG) << "Incidence description is rich "
-                                     << mLoadedIncidence->descriptionIsRich();
+        qCDebug(INCIDENCEEDITOR_LOG) << "Incidence description is rich " << mLoadedIncidence->descriptionIsRich();
 
         if (mLoadedIncidence->descriptionIsRich()) {
-            qCDebug(INCIDENCEEDITOR_LOG) << "desc is rich, and it is <desc>"
-                                         <<  mLoadedIncidence->richDescription()
-                                         << "</desc>; "
-                                         << "widget has <desc>"
-                                         << mUi->mDescriptionEdit->richTextComposer()->toHtml()
-                                         << "</desc>; "
-                                         <<
-                "expr mLoadedIncidence->richDescription() != mUi->mDescriptionEdit->toHtml() is "
-                                         << (mLoadedIncidence->richDescription()
-                != mUi->mDescriptionEdit->richTextComposer()->toHtml());
+            qCDebug(INCIDENCEEDITOR_LOG) << "desc is rich, and it is <desc>" << mLoadedIncidence->richDescription() << "</desc>; "
+                                         << "widget has <desc>" << mUi->mDescriptionEdit->richTextComposer()->toHtml() << "</desc>; "
+                                         << "expr mLoadedIncidence->richDescription() != mUi->mDescriptionEdit->toHtml() is "
+                                         << (mLoadedIncidence->richDescription() != mUi->mDescriptionEdit->richTextComposer()->toHtml());
         } else {
-            qCDebug(INCIDENCEEDITOR_LOG) << "desc is not rich, and it is <desc>"
-                                         << mLoadedIncidence->description()
-                                         << "</desc>; "
-                                         << "widget has <desc>"
-                                         << mUi->mDescriptionEdit->richTextComposer()->toPlainText()
-                                         << "</desc>; "
-                                         <<
-                "expr mLoadedIncidence->description() != mUi->mDescriptionEdit->toPlainText() is "
-                                         << (mLoadedIncidence->description()
-                != mUi->mDescriptionEdit->richTextComposer()->toPlainText());
+            qCDebug(INCIDENCEEDITOR_LOG) << "desc is not rich, and it is <desc>" << mLoadedIncidence->description() << "</desc>; "
+                                         << "widget has <desc>" << mUi->mDescriptionEdit->richTextComposer()->toPlainText() << "</desc>; "
+                                         << "expr mLoadedIncidence->description() != mUi->mDescriptionEdit->toPlainText() is "
+                                         << (mLoadedIncidence->description() != mUi->mDescriptionEdit->richTextComposer()->toPlainText());
         }
     } else {
         qCDebug(INCIDENCEEDITOR_LOG) << "Incidence is invalid";
