@@ -10,11 +10,13 @@
 
 #include "incidenceeditor-ng.h"
 
-namespace Ui {
+namespace Ui
+{
 class EventOrTodoDesktop;
 }
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 class IncidenceDescriptionPrivate;
 
 /**
@@ -25,8 +27,8 @@ class IncidenceDescription : public IncidenceEditor
 {
     Q_OBJECT
 public:
-    using IncidenceEditorNG::IncidenceEditor::save; // So we don't trigger -Woverloaded-virtual
     using IncidenceEditorNG::IncidenceEditor::load; // So we don't trigger -Woverloaded-virtual
+    using IncidenceEditorNG::IncidenceEditor::save; // So we don't trigger -Woverloaded-virtual
 
     explicit IncidenceDescription(Ui::EventOrTodoDesktop *ui);
 
